spannertools.fracture_spanners_attached_to_component
====================================================

.. autofunction:: abjad.tools.spannertools.fracture_spanners_attached_to_component.fracture_spanners_attached_to_component
   :noindex:
